@@ -12,12 +12,16 @@ local b = B:new()
 assert(tolua.type(A.last) == 'Tst_B') -- no convertion: obj already mapped as B
 local c = luaC:new(0)
 assert(tolua.type(A.last) == 'Tst_C') -- no convertion: obj already mapped as C
-assert(tolua.type(luaC.last) == 'Tst_C') 
-
+assert(tolua.type(luaC.last) == 'Tst_C')
 local aa = A.AA:new()
 local bb = A.BB:new()
 local xx = create_aa()
 
+-- casting test
+local base = bb:Base();
+local derived = tolua.cast(base,"Tst_A::Tst_BB");
+assert(derived:classname()=="Tst_BB")
+
 -- method calling tests
 assert(a:a() == 'A')
 assert(b:a() == 'A')
@@ -36,10 +40,10 @@ remark = [[
 local set = {}
 for i=1,10 do
  local c = luaC:new(i)
-	tolua.takeownership(c)
-	set[i] = c
+  tolua.takeownership(c)
+  set[i] = c
 end
- 
+
 for i=1,5 do
  tolua.releaseownership(set[i])
 end
