@@ -8,7 +8,7 @@ int main ()
 {
 	int  tolua_tinheritance_open (lua_State*);
 
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 	luaL_openlibs(L);
 	tolua_tinheritance_open(L);
 
