@@ -5,8 +5,8 @@ class A
 public:
 	A () {}
   virtual ~A() {}
-  virtual char* aname () { return "A"; }
-	virtual char* name () { return "A"; } 
+  virtual const char* aname () { return "A"; }
+	virtual const char* name () { return "A"; } 
 };
 
 class B : public A
@@ -14,7 +14,7 @@ class B : public A
 public:
 	B () {}
   virtual ~B() {}
-	virtual char* name () { return "B"; } 
+	virtual const char* name () { return "B"; } 
 };
 
 class C : public B
@@ -22,7 +22,7 @@ class C : public B
 public:
 	C () {}
   virtual ~C() {}
-	virtual char* name () { return "C"; } 
+	virtual const char* name () { return "C"; } 
 };
 
 class D : public C
@@ -30,6 +30,6 @@ class D : public C
 public:
 	D () {}
   virtual ~D() {}
-	virtual char* name () { return "D"; } 
+	virtual const char* name () { return "D"; } 
 };
 
