@@ -13,7 +13,7 @@ int main ()
 {
 	int  tolua_tnamespace_open (lua_State*);
 
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 	luaL_openlibs(L);
 	tolua_tnamespace_open(L);
 
