@@ -16,8 +16,9 @@ public:
   {
     return v[i];
   }
-  int bounce (int i)
+  int bounce (int i, int* j, int* k)
   {
+    *k = i;
     return i;
   }
   double add (lua_State* L)
